ACEQUIA
=======

Acequia is a python package to facilitate data conversions of 
groundwater head measurements. It's primary aim is to provide 
tools to easily read and write common file formats and calculate 
descriptive statistics from groundwater head time series. 

Acequia is written from the perspective of Dutch groundwater 
practitioners who deal with files from Dinoloket, Menyanthes,
and KNMI for hydrological time series analysis.


Dependencies
------------
Acequia uses the following packages:
numpy, scipy, pandas, maplotlib, statsmodels, seaborn, geopandas,
simplekml.

The package simplekml is available on pip:
pip install simplekml



 